<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.PersonalInformation.Provisioning

Windows Runtime (WinRT) APIs for for the `Windows.Phone.PersonalInformation.Provisioning` namespace.

This package provides the `winrt.windows.phone.personalinformation.provisioning` module.
